# gsuite-python-library
Python library to interact with Google Suite API

Google Services which are currently supported are:
* Google Groups
* Google Sheets

## Requirements

* [Python 3.X.X](https://www.python.org/downloads/)
* [Virtualenv](https://virtualenv.pypa.io/en/latest/) (Recommended)

## Installation

You can use `pip` and `virtualenv`. Create a new virtual environment, then activate the environment and use this command to install:
```bash
$ pip install gsuite
```

Or you can do it without `virtualenv`. `sudo` most likely be required:
```bash
$ sudo pip install gsuite
```

## Author

* [Rafi Kurnia Putra](https://github.com/rafikurnia)

## License

Apache 2 Licensed. See [LICENSE](https://github.com/traveloka/gsuite-python-library/blob/master/LICENSE) for full details.